@@ -1,14 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Keywords;
-BEGIN {
-  $Dist::Zilla::Plugin::Keywords::AUTHORITY = 'cpan:ETHER';
-}
-# git description: v0.005-12-gc788898
-$Dist::Zilla::Plugin::Keywords::VERSION = '0.006';
+package Dist::Zilla::Plugin::Keywords; # git description: v0.006-22-g3b1a3ad
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Add keywords to metadata in your distribution
 # KEYWORDS: plugin distribution metadata cpan-meta keywords
-# vim: set ts=8 sw=4 tw=78 et :
+
+our $VERSION = '0.007';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -16,7 +13,7 @@ with 'Dist::Zilla::Role::MetaProvider',
 use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose 'ArrayRef';
 use MooseX::Types::Common::String 'NonEmptySimpleStr';
-use Encode;
+use Encode ();
 use namespace::autoclean;
 
 my $word = subtype NonEmptySimpleStr,
@@ -48,6 +45,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         keywords => $self->keywords,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
     return $config;
 };
@@ -77,8 +75,11 @@ sub keywords_from_file
     );
     return if not $keywords;
 
-    # TODO: skip decoding logic if/when PPI is new enough
-    $keywords = Encode::decode($file->encoding, $keywords, Encode::FB_CROAK);
+    if (not eval { Dist::Zilla::Role::PPI->VERSION('6.003') })
+    {
+        # older Dist::Zilla::Role::PPI passes encoded content to PPI
+        $keywords = Encode::decode($file->encoding, $keywords, Encode::FB_CROAK);
+    }
 
     $self->log_debug('found keyword string in main module: ' . $keywords);
     return split /\s+/, $keywords;
@@ -98,7 +99,7 @@ Dist::Zilla::Plugin::Keywords - Add keywords to metadata in your distribution
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -137,14 +138,6 @@ Strings are broken up by whitespace and added as separate words.
 If no configuration is provided, the main module of your distribution is
 scanned for the I<first> C<# KEYWORDS:> comment.
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Keywords>
-(or L<bug-Dist-Zilla-Plugin-Keywords@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Keywords@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -155,11 +148,24 @@ L<CPAN::Meta::Spec/keywords>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Keywords>
+(or L<bug-Dist-Zilla-Plugin-Keywords@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Keywords@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
